%define anolis_release 3

Name:           acpica-tools
Version:        20221020
Release:        %{anolis_release}%{?dist}
Summary:        ACPICA tools for the development and debug of ACPI tables
License:        GPLv2
URL:            https://www.acpica.org/
Source0: 	https://github.com/acpica/acpica/archive/refs/tags/R10_20_22.tar.gz

# replace upstream man pages for license reason
Source10:       iasl.1
Source11:       acpibin.1
Source12:       acpidump.1
Source13:       acpiexec.1
Source14:       acpihelp.1
Source15:       acpisrc.1
Source16:       acpixtract.1
Source17:       acpiexamples.1

Source20:       COPYING

Patch100:	dangling-ptr.patch
Patch101:	0001-Add-loongarch-support-for-acpica-tools.patch

BuildRequires:	make
BuildRequires:  bison patchutils flex gcc

Provides:       acpixtract >= 20120913-7
Provides:       iasl = %{version}-%{release}
Obsoletes:      iasl < 20120913-8

Provides:       acpidump >= 20100513-5
Provides:       pmtools = %{version}-%{release}
Obsoletes:      pmtools < 20100513-6

%description
The ACPI Component Architecture (ACPICA) project provides an OS-independent
reference implementation of the Advanced Configuration and Power Interface
Specification (ACPI).  ACPICA code contains those portions of ACPI meant to
be directly integrated into the host OS as a kernel-resident subsystem, and
a small set of tools to assist in developing and debugging ACPI tables.

This package contains only the user-space tools needed for ACPI table
development, not the kernel implementation of ACPI.  The following commands
are installed:
   -- iasl: compiles ASL (ACPI Source Language) into AML (ACPI Machine
      Language), suitable for inclusion as a DSDT in system firmware.
      It also can disassemble AML, for debugging purposes.
   -- acpibin: performs basic operations on binary AML files (e.g.,
      comparison, data extraction)
   -- acpidump: write out the current contents of ACPI tables
   -- acpiexec: simulate AML execution in order to debug method definitions
   -- acpihelp: display help messages describing ASL keywords and op-codes
   -- acpisrc: manipulate the ACPICA source tree and format source files
      for specific environments
   -- acpixtract: extract binary ACPI tables from acpidump output (see
      also the pmtools package)

This version of the tools is being released under GPLv2 license.

%package doc
Summary: Doc files for %{name}
Requires: %{name} = %{EVR}
BuildArch: noarch

%description doc
Doc files for %{name}

%prep
%autosetup -n acpica-R10_20_22 -p1

cp -a -- \
	%{SOURCE10} %{SOURCE11} %{SOURCE12} %{SOURCE13} \
	%{SOURCE14} %{SOURCE15} %{SOURCE16} %{SOURCE17} \
	%{SOURCE20} \
	.

# spurious executable permissions on text files in upstream
chmod a-x source/compiler/new_table.txt


%build
CWARNINGFLAGS="\
    -std=c99\
    -Wall\
    -Wbad-function-cast\
    -Wdeclaration-after-statement\
    -Werror\
    -Wformat=2\
    -Wmissing-declarations\
    -Wmissing-prototypes\
    -Wstrict-aliasing=0\
    -Wstrict-prototypes\
    -Wswitch-default\
    -Wpointer-arith\
    -Wundef\
    -Waddress\
    -Waggregate-return\
    -Winit-self\
    -Winline\
    -Wmissing-declarations\
    -Wmissing-field-initializers\
    -Wnested-externs\
    -Wold-style-definition\
    -Wno-format-nonliteral\
    -Wredundant-decls\
    -Wempty-body\
    -Woverride-init\
    -Wlogical-op\
    -Wmissing-parameter-type\
    -Wold-style-declaration\
    -Wtype-limits"

OPT_CFLAGS="%{optflags} $CWARNINGFLAGS"
OPT_LDFLAGS="%{__global_ldflags}"
export OPT_CFLAGS
export OPT_LDFLAGS

%make_build


%install
# Install the binaries
mkdir -p %{buildroot}%{_bindir}
install -pD generate/unix/bin*/* %{buildroot}%{_bindir}/

# Install the man pages
mkdir -p %{buildroot}%{_mandir}/man1
install -pDm 0644 *.1 %{buildroot}%{_mandir}/man1/

# Install the examples source code
mkdir -p %{buildroot}%{_docdir}/acpica-tools/examples
install -pDm 0644 source/tools/examples/* %{buildroot}%{_docdir}/acpica-tools/examples/

%generate_compatibility_deps

%check
cd tests
# ASL tests
./aslts.sh                         # relies on non-zero exit

%pre
if [ -e %{_bindir}/acpixtract-acpica ]
then
    alternatives --remove acpixtract %{_bindir}/acpixtract-acpica
fi
if [ -e %{_bindir}/acpidump-acpica ]
then
    alternatives --remove acpidump %{_bindir}/acpidump-acpica
fi

%postun
if [ -e %{_bindir}/acpixtract-acpica ]
then
    alternatives --remove acpixtract %{_bindir}/acpixtract-acpica
fi
if [ -e %{_bindir}/acpidump-acpica ]
then
    alternatives --remove acpidump %{_bindir}/acpidump-acpica
fi


%files
%license COPYING
%{_bindir}/*
%{_mandir}/*/*
%{_docdir}/*/*
%dir %{abidir}
%{abidir}/*-option.list

%files doc
%doc source/compiler/new_table.txt

%changelog
* Wed Dec 27 2023 happy_orange <songnannan@linux.alibaba.com> - 20221020-3
- fix the source error

* Thu Sep 28 2023 Wenlong Zhang <zhangwenlong@loongson.cn> - 20221020-2
- Add loongarch support for acpica-tools

* Wed Mar 15 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 20221020-1
- init from upstream
